@@ -38,18 +38,34 @@ def fmt_cmd_options(options: list[CommandOption]) -> str:
             )
 
 
-def fmt_help(option: CommandOption, show_default: bool):
+def fmt_help(option: CommandOption, show_default: bool,
+             *,
+             markdown_open: Optional[str] = '[bold]',
+             markdown_close: Optional[str] = '[/bold]'):
+    _choices = option.get_choices()
+    _markdown_open, _markdown_close = markdown_open or '', markdown_close or ''
+
     if show_default and option.default is not None and not option.is_required:
-        default_str = f'[bold](default: {option.default})[/bold]'
+        default_str = option.default if not option.is_password else '******'
+        default_str = f'{_markdown_open}(default: {default_str}){_markdown_close}'
         return option.help + f' {default_str}' if option.help else default_str
+    elif _choices is not None and not option.hide_choices:
+        if len(_choices) <= 3:
+            possible_choices = ', '.join(str(_choice) for _choice in _choices)
+            choices_help = f'{_markdown_open}(choices are: {possible_choices}){_markdown_close}'
+        else:
+            sep = ' \n - '
+            possible_choices = sep + sep.join(str(_choice) for _choice in _choices)
+            choices_help = f'\n{_markdown_open}Possible choices are:' + possible_choices + _markdown_close
+        return option.help + f' {choices_help}' if option.help else choices_help
     else:
         return option.help
 
 
 def get_usage(global_options: list[CommandOption],
-              command: str = None,
-              command_options: list[CommandOption] = None,
-              parent_args: ParentArgs = None):
+              command: Optional[str] = None,
+              command_options: Optional[list[CommandOption]] = None,
+              parent_args: Optional[ParentArgs] = None):
     parent_args = parent_args or []
     _global_options = ' '.join(['[' + sorted(x.keyword_args)[-1] + ']' for x in global_options])
     command = f'[underline]{command}[/underline]' if command else '<command>'
@@ -88,14 +104,15 @@ class RichFormatter(Formatter):
                                                               highlight=False))
     cmd_color: str = 'cyan'
     option_color: str = 'cyan'
+    default_color: str = 'white'
     show_default: bool = True
-    use_markdown: bool = True
     """Use Markdown object for the description, otherwise use 
     default str
     """
-    # Only if use_markdown is True
-    code_theme: str = 'solarized-dark'
+    use_markdown: bool = True
     """See https://pygments.org/styles/ for a list of styles """
+    # Only usable if use_markdown is True
+    code_theme: str = 'solarized-dark'
 
     def _color_cmd(self, cmd: str):
         return f'[{self.cmd_color}]{cmd}[/{self.cmd_color}]'
@@ -116,9 +133,14 @@ class RichFormatter(Formatter):
             else:
                 self.print_fn(pad(description))
 
+    def _fmt_help(self, option: CommandOption):
+        return fmt_help(option, self.show_default,
+                        markdown_open=f'[{self.default_color}][bold]',
+                        markdown_close=f'[/{self.default_color}][/bold]')
+
     def _print_options(self, options: list[CommandOption]):
         self.print_rows([(fmt_option(opt, show_full=True, color=self.option_color),
-                          fmt_help(opt, show_default=self.show_default))
+                          self._fmt_help(opt))
                          for opt in options])
 
     def print_rows(self, rows: list[tuple[str, Optional[str]]]):
@@ -148,12 +170,12 @@ class RichFormatter(Formatter):
     def print_cmd_help(self,
                        command: Command,
                        options: list[CommandOption],
-                       parent_args: ParentArgs = None):
+                       parent_args: Optional[ParentArgs] = None):
 
         usage = get_usage(
             global_options=options,
             command=command.name,
-            command_options=command.options,
+            command_options=command.options_sorted,
             parent_args=parent_args
         )
         self.print_fn(RichTitles.USAGE)
@@ -163,7 +185,7 @@ class RichFormatter(Formatter):
         if command.positional_args:
             self.print_fn(RichTitles.ARGUMENTS)
             self.print_rows(
-                [(fmt_option(option, color=self.option_color), fmt_help(option, show_default=self.show_default))
+                [(fmt_option(option, color=self.option_color), self._fmt_help(option))
                  for option in command.positional_args])
         if command.keyword_args:
             self.print_fn('\n' + RichTitles.OPTIONS)
@@ -190,7 +212,7 @@ class RichFormatter(Formatter):
                 if group.options and cmd_lvl == len(parent_commands) - 1:
                     _cmds.append(fmt_cmd_options(group.options))
             _cmds_str = ' '.join(_cmds)
-            _line = f'{"" if i == 0 else "or: ":>5}{_cmds_str} {fmt_cmd_options(cmd.options)}'.rstrip()
+            _line = f'{"" if i == 0 else "or: ":>5}{_cmds_str} {fmt_cmd_options(cmd.options_sorted)}'.rstrip()
             commands_str.append(_line)
         commands_str = '\n'.join(commands_str)
 
@@ -207,8 +229,8 @@ class RichFormatter(Formatter):
                 self.print_fn()
             if cmd.options:
                 self.print_rows([(fmt_option(opt, show_full=True, color=self.option_color),
-                                  fmt_help(opt, show_default=self.show_default))
-                                 for opt in cmd.options])
+                                  self._fmt_help(opt))
+                                 for opt in cmd.options_sorted])
                 self.print_fn()
 
         if group.options:
@@ -239,3 +261,9 @@ class RichFormatter(Formatter):
     def print_count_error(self, expected_count: int, count: int, cmd: str):
         self.print_fn(
             f'[red]Expected {expected_count} positional arguments but got {count} for command [bold]{cmd}[/bold][/red]')
+
+    def print_invalid_value_error(self, value: str, choices: list[str]):
+        sep = '\n - '
+        possible_fields = sep + sep.join(_choice for _choice in choices)
+        msg = f'Invalid value [bold]{value}[/bold] found. Possible values are: {possible_fields}'
+        self.print_fn(f'[red]{msg}[/red]')
